@@ -1,8 +1,9 @@
-from .CameraContext import CameraContext
-from .GraphComponent import GraphComponent
 from .JsonView import JsonView
 from .MatSidebar import MatSidebar
-from .Simple3DScene import Simple3DScene
+from .CameraContextProvider import CameraContextProvider
+from .CrystalToolkitScene import CrystalToolkitScene
+from .Download import Download
+from .GraphComponent import GraphComponent
 from .NavbarDropdown import NavbarDropdown
 from .Scrollspy import Scrollspy
 from .PeriodicContext import PeriodicContext
@@ -14,11 +15,12 @@ from .GlobalSearchBar import GlobalSearchBar
 from .SearchUI import SearchUI
 
 __all__ = [
-    "CameraContext",
-    "GraphComponent",
     "JsonView",
     "MatSidebar",
-    "Simple3DScene",
+    "CameraContextProvider",
+    "CrystalToolkitScene",
+    "Download",
+    "GraphComponent",
     "NavbarDropdown",
     "Scrollspy",
     "PeriodicContext",
